pub enum ExecutionError {
Timeout,
Uninitialized,
Disconnected,
PoolPoisoned,
}Expand description
Enumeration to indicate possible reasons a job execution request is rejected. User will need to resubmit the job again, since closure’s state may have been stale at the execution error.
Variants
Timeout
The job can’t be executed because the queue is full when the new job is submitted and no new worker becomes available before predetermined timeout period.
Uninitialized
The pool hasn’t been initialized (i.e. lazy created), or all workers have been terminated, such that there is no working threads to execute the job
Disconnected
The pool is shutting down, or the internal pipeline is broken for whatever reasons.
PoolPoisoned
Pool’s internal states have been corrupted